@@ -15,9 +15,9 @@ Bord::~Bord()
 
 void Bord::draw( QPainter* aPainter )
 {
-    foreach( QPoint mWallPoint, mWall ) {
-        aPainter->drawRect( QRect( mWallPoint, QSize(20,20)) );
-        aPainter->fillRect( QRect( mWallPoint, QSize(20,20)), Qt::darkMagenta );
+    foreach( QRect wallRect, mWall ) {
+        aPainter->drawRect( wallRect );
+        aPainter->fillRect( wallRect, Qt::darkMagenta );
     }
 }
 
@@ -28,8 +28,8 @@ bool Bord::isColliding( Snake* aSnake )
 
 bool Bord::isColliding( QPoint aPoint )
 {
-    foreach( QPoint mWallPoint, mWall ) {
-        if( aPoint == mWallPoint ) {
+    foreach( QRect wallRect, mWall ) {
+        if( wallRect.contains( aPoint )) {
             return true;
         }
     }
