@@ -5,6 +5,7 @@
 
 class Snake;
 class QPoint;
+class QRect;
 class QPainter;
 
 class Bord
@@ -25,7 +26,9 @@ protected:
 
 protected:
 
-    QList<QPoint> mWall;
+    //QList<QPoint> mWall;
+    QList<QRect> mWall;
+
 
 };
 
