@@ -32,6 +32,25 @@ void MotionSenser::sendEvent()
 {    
     readCurrentPos();
 
+    int xDiff = qAbs( mLastPos.x() - mCurrentPos.x() );
+    int yDiff = qAbs( mLastPos.y() - mCurrentPos.y() );
+
+    if( xDiff > yDiff && xDiff >= 800 ) {
+
+        if( mLastPos.x() < mCurrentPos.x() ) {
+            emit keyEvent( QPoint( -1,0));
+        } else {
+           emit keyEvent( QPoint( 1,0));
+        }
+
+    } else if ( yDiff >= 800 ) {
+
+        if( mLastPos.y() < mCurrentPos.y() ) {
+            emit keyEvent( QPoint( 0,-1));
+        } else {
+            emit keyEvent( QPoint( 0,1));
+        }
+    }
 
     mLastPos = mCurrentPos;
 }
@@ -53,7 +72,6 @@ void MotionSenser::readCurrentPos()
         mCurrentPos.setX(x*10);
         mCurrentPos.setY(y*10);
 
-        ////qDebug() << "Location::" << mCurrentPos;        
         f.close();
     }
 }
